@@ -140,5 +140,5 @@ setClass(
 )
 
 check.results <- function(obj){
-  if (class(obj)!="VSLCMresults") stop("Results must be an instance of VSLCMresults returned by the function VarSelCluster of R package VarSelLCM")
+  if (!inherits(obj,"VSLCMresults")) stop("Results must be an instance of VSLCMresults returned by the function VarSelCluster of R package VarSelLCM")
 }
\ No newline at end of file
